import os
import shutil

from ..constants import TEMPLATE_DIR_PTH


def copying_template(dock):


    ## handle the case when the template already exists
    if os.path.isdir( os.path.join(dock, '_layouts') ):
        shutil.rmtree( os.path.join(dock, '_layouts') )
    if os.path.isdir( os.path.join(dock, '_sass') ):
        shutil.rmtree( os.path.join(dock, '_sass') )
    if os.path.isdir( os.path.join(dock, 'scripts') ):
        shutil.rmtree( os.path.join(dock, 'scripts') )


    shutil.copytree(
        os.path.join(TEMPLATE_DIR_PTH, '_layouts'),
        os.path.join(dock, '_layouts')
    )

    shutil.copytree(
        os.path.join(TEMPLATE_DIR_PTH, '_sass'),
        os.path.join(dock, '_sass')
    )

    shutil.copytree(
        os.path.join(TEMPLATE_DIR_PTH, 'scripts'),
        os.path.join(dock, 'scripts')
    )


import os
import pkg_resources


try:
    __version__ = pkg_resources.get_distribution('nics').version
except pkg_resources.DistributionNotFound:  # this exception occurred during development (before the software installed via pip)
    __version__ = 'dev'


SOFTWARE_REPO = 'https://github.com/nvfp/now-i-can-sleep'
SOFTWARE_NAME = 'Now I Can Sleep'
SOFTWARE_DIST_NAME = 'nics'  # distribution name

ROOT_DIR_PTH = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
DIST_DIR_PTH = os.path.join(ROOT_DIR_PTH, SOFTWARE_DIST_NAME)

TEMPLATE_DIR_PTH = os.path.join(DIST_DIR_PTH, 'template')